# MyLibrary

A simple Python library for greeting and basic calculations.

## Installation

```bash
pip install .

How to build a distributed package:

To create a distributable package, you need to build it. Run the following commands:

```bash
pip install setuptools wheel  # Install required tools
python setup.py sdist bdist_wheel  # Build the package


## To install it locally:

```bash
pip install .

then try to: 

```bash
pip list

this will output all installed packages.

Installed lib should be there.